/* eslint-disable */
// @ts-nocheck
import Vue from 'vue';
import Router from 'vue-router';
import { Config, Http } from '@zeedhi/core';
import { TekLibLocalStorage } from '@zeedhi/tek-lib';
import { LoadingService } from '@zeedhi/common';
import routes from './routes';
import Store from '../store';

Vue.use(Router);

const router = new Router({
  mode: 'history',
  base: Config.env.BASE_URL,
  routes,
});

const isOpeningNewModule = function isOpeningNewModule(to: any, from: any) {
  const isFromProduct = (to.name === 'microservice' && from.name !== 'microservice');
  // eslint-disable-next-line max-len
  const isFromAnotherModule = ((to.name === 'microservice' && from.name === 'microservice') && to.path.split('/')[2] !== from.path.split('/')[2]);
  const isNotLoginRoute = (to.fullPath !== Config.env.modules.login.routePath);
  return ((isFromProduct || isFromAnotherModule) && isNotLoginRoute);
};

// eslint-disable-next-line max-len
const callLibStartSessionFromModule = async function callLibStartSessionFromModule(to: any) {
  const data = {
    USER: localStorage.getItem('LOGIN_USER'),
    LOGIN_LANGUAGE: localStorage.getItem('LOGIN_LAGUAGE'),
    LOGIN_TOKEN: localStorage.getItem('LOGIN_TOKEN'),
  };
  await Http.post(`${Config.env.modules[to.path.split('/')[2]].endPoint}/lib_startSession`, data);
};

router.beforeEach(async (to, from, next) => {
  /** Somente enqunto não logar por conta proria - Início *//** open old application - init */
	if (window.parent !== window && to.name !== 'token-error' && to.query.isZhAngular === '1') { // if application is called inside a iframe
		if (to.query.token) {
			// if token was passed
			localStorage.setItem('LOGIN_TOKEN', to.query.token.toString());
			localStorage.setItem('LOGIN_USER', to.query.user.toString());
			localStorage.setItem('LOGIN_LANGUAGE', to.query.languange.toString());
			localStorage.setItem('PRODUCT_ID', to.query.productId.toString());
			if (to.query.hash !== '0') {
				localStorage.setItem('LOGIN_HASH', to.query.hash.toString());
			}
			Store.commit('setAppLoginToken', to.query.token);
			Store.commit('setAppDisplayOptions', { menu: to.query.menu, header: to.query.header });
		}

		if (!Store.state.appLoginToken) {
			// if there is no token... redirect to another page
			Store.commit('setAppDisplayOptions', { menu: '0', header: '0' });
			next('/token-error');
			return;
		}

		// remove parameters from requested page
		delete to.query.menu;
		delete to.query.header;
		delete to.query.token;

		TekLibLocalStorage.setItem('IS_NEXT', false);
		TekLibLocalStorage.setItem('LOGIN_KEEP_CONNECTED', 'Yes');
		TekLibLocalStorage.removeItem('routeParams');

		next();
	} else {
		TekLibLocalStorage.setItem('IS_NEXT', true);
	}
	/** Somente enqunto não logar por conta proria - Fim */ /** open old application - end */

  if (isOpeningNewModule(to, from) && TekLibLocalStorage.getItem('IS_NEXT')) {
    try {
      LoadingService.show();
      await callLibStartSessionFromModule(to);
      LoadingService.hide();
    } catch (e) {
      LoadingService.hide();
    }
  }

  TekLibLocalStorage.setItem('IS_NEXT', true);

  if (to.path !== Config.env.loginRoutePath && !localStorage.getItem('LOGIN_TOKEN')) {
    next(Config.env.loginRoutePath);
  } else if (to.path === Config.env.loginRoutePath && localStorage.getItem('LOGIN_TOKEN')) {
    next(Config.env.baseUrl);
  } else {
    next();
  }
});

router.afterEach((to, from) => {
  const htmlElement = document.getElementsByTagName('html')[0];
  if (to.name === 'microservice') {
    htmlElement.setAttribute('microservice', '');
    Store.commit('setRouterParams', to.params);
    const frame = (document.getElementById('microservice-frame') as HTMLIFrameElement);
    if (frame && frame.contentWindow && to.path.split('/')[2] === from.path.split('/')[2]) {
      frame.contentWindow.postMessage({
        type: 'microservice-route-change',
        routerParams: to.params,
      }, `${Config.env.modules[to.path.split('/')[2]].baseUrl}`);
    }
    window.document.title = `${Config.env.product.name} - ${to.params.page}`;
  } else {
    htmlElement.removeAttribute('microservice');
    window.document.title = Config.env.product.name;
  }

  if (to.name === 'login') {
    htmlElement.setAttribute('login', '');
  } else {
    htmlElement.removeAttribute('login');
  }
});

export default router;
